Index: build/pom.xml
===================================================================
--- build/pom.xml	(revision 5874)
+++ build/pom.xml	(working copy)
@@ -80,6 +80,8 @@
                      <exclude>org.apache.tomcat:annotations-api</exclude>
                      <exclude>javax.faces:jsf-api</exclude>
                      <exclude>javax.el:el-api</exclude>
+                     <exclude>org.mortbay.jetty:jetty</exclude>
+                     <exclude>org.mortbay.jetty:jetty-annotations</exclude>
                   </excludes>
                </artifactSet>
             </configuration>
Index: int/pom.xml
===================================================================
--- int/pom.xml	(revision 5874)
+++ int/pom.xml	(working copy)
@@ -41,6 +41,12 @@
       </dependency>
 
       <dependency>
+         <groupId>org.jboss.weld.servlet</groupId>
+         <artifactId>weld-jetty-support</artifactId>
+         <scope>provided</scope>
+      </dependency>
+
+      <dependency>
          <groupId>javax.servlet</groupId>
          <artifactId>servlet-api</artifactId>
          <scope>provided</scope>
Index: int/src/main/java/org/jboss/weld/environment/jetty/JettyWeldInjector.java
===================================================================
--- int/src/main/java/org/jboss/weld/environment/jetty/JettyWeldInjector.java	(revision 0)
+++ int/src/main/java/org/jboss/weld/environment/jetty/JettyWeldInjector.java	(revision 0)
@@ -0,0 +1,22 @@
+package org.jboss.weld.environment.jetty;
+
+import org.jboss.weld.environment.servlet.inject.AbstractInjector;
+import org.jboss.weld.manager.api.WeldManager;
+
+/**
+ *  
+ *
+ * @author <a href="mailto:matija.mazi@gmail.com">Matija Mazi</a>
+ */
+public class JettyWeldInjector extends AbstractInjector implements Injector
+{
+   public JettyWeldInjector(WeldManager manager)
+   {
+      super(manager);
+   }
+
+   public void inject(Object targetInstance)
+   {
+      super.inject(targetInstance);
+   }
+}
Index: int/src/main/java/org/jboss/weld/environment/servlet/inject/AbstractInjector.java
===================================================================
--- int/src/main/java/org/jboss/weld/environment/servlet/inject/AbstractInjector.java	(revision 0)
+++ int/src/main/java/org/jboss/weld/environment/servlet/inject/AbstractInjector.java	(revision 0)
@@ -0,0 +1,67 @@
+/*
+ * JBoss, Home of Professional Open Source.
+ * Copyright 2010, Red Hat Middleware LLC, and individual contributors
+ * as indicated by the @author tags. See the copyright.txt file in the
+ * distribution for a full listing of individual contributors.
+ *
+ * This is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation; either version 2.1 of
+ * the License, or (at your option) any later version.
+ *
+ * This software is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this software; if not, write to the Free
+ * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+ */
+
+package org.jboss.weld.environment.servlet.inject;
+
+import org.jboss.weld.manager.api.WeldManager;
+
+import javax.enterprise.context.spi.CreationalContext;
+import javax.enterprise.inject.spi.InjectionTarget;
+import java.util.Map;
+import java.util.WeakHashMap;
+
+/**
+ * Provides support for Weld injection into servlets, servlet filters etc.
+ *
+ * Used to wrap the Weld classes (WeldManager) so that they are not seen from jetty-support.
+ * jetty-support thus does not depend on Weld, which is deployed within the war and may be
+ * deployed several times (within several wars) in a single servlet container.
+ *
+ * @author Pete Muir
+ * @author <a href="mailto:matija.mazi@gmail.com">Matija Mazi</a>
+ */
+public abstract class AbstractInjector
+{
+   private final WeldManager manager;
+   private final Map<Class<?>, InjectionTarget<?>> cache = new WeakHashMap<Class<?>, InjectionTarget<?>>();
+
+   protected AbstractInjector(WeldManager manager)
+   {
+      if (manager == null)
+         throw new IllegalArgumentException("Null manager");
+      this.manager = manager;
+   }
+
+   protected void inject(Object instance)
+   {
+      // not data-race safe, however doesn't matter, as the injection target created for class A is interchangable for another injection target created for class A
+      // TODO Make this a concurrent cache when we switch to google collections
+      Class<?> clazz = instance.getClass();
+      if (!cache.containsKey(clazz))
+      {
+         cache.put(clazz, manager.createInjectionTarget(manager.createAnnotatedType(clazz)));
+      }
+      CreationalContext<Object> cc = manager.createCreationalContext(null);
+      InjectionTarget<Object> it = (InjectionTarget<Object>) cache.get(clazz);
+      it.inject(instance, cc);
+   }
+}
\ No newline at end of file
Index: int/src/main/java/org/jboss/weld/environment/servlet/Listener.java
===================================================================
--- int/src/main/java/org/jboss/weld/environment/servlet/Listener.java	(revision 5874)
+++ int/src/main/java/org/jboss/weld/environment/servlet/Listener.java	(working copy)
@@ -18,16 +18,12 @@
 
 import javassist.util.proxy.ProxyFactory;
 import javassist.util.proxy.ProxyFactory.ClassLoaderProvider;
-
-import javax.el.ELContextListener;
-import javax.servlet.ServletContextEvent;
-import javax.servlet.jsp.JspApplicationContext;
-import javax.servlet.jsp.JspFactory;
-
 import org.jboss.weld.bootstrap.api.Bootstrap;
 import org.jboss.weld.bootstrap.api.Environments;
 import org.jboss.weld.context.api.BeanStore;
 import org.jboss.weld.context.api.helpers.ConcurrentHashMapBeanStore;
+import org.jboss.weld.environment.jetty.Injector;
+import org.jboss.weld.environment.jetty.JettyWeldInjector;
 import org.jboss.weld.environment.servlet.deployment.ServletDeployment;
 import org.jboss.weld.environment.servlet.services.ServletResourceInjectionServices;
 import org.jboss.weld.environment.servlet.services.ServletServicesImpl;
@@ -41,6 +37,11 @@
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import javax.el.ELContextListener;
+import javax.servlet.ServletContextEvent;
+import javax.servlet.jsp.JspApplicationContext;
+import javax.servlet.jsp.JspFactory;
+
 /**
  * @author Pete Muir
  */
@@ -56,7 +57,7 @@
    private final transient Bootstrap bootstrap;
    private final transient ServletListener weldListener;
    private WeldManager manager;
-   
+
    public Listener()
    {
       try
@@ -87,6 +88,12 @@
          sce.getServletContext().removeAttribute(WeldAnnotationProcessor.class.getName());
       }
       catch (IllegalArgumentException e) {}
+      try
+      {
+         Reflections.classForName(Injector.class.getName());
+         sce.getServletContext().removeAttribute(Injector.class.getName());
+      }
+      catch (IllegalArgumentException ignore) {}
       super.contextDestroyed(sce);
    }
 
@@ -123,7 +130,7 @@
       
       bootstrap.startContainer(Environments.SERVLET, deployment, applicationBeanStore).startInitialization();
       manager = bootstrap.getManager(deployment.getWebAppBeanDeploymentArchive());
-      
+
       boolean tomcat = true;
       try
       {
@@ -131,10 +138,9 @@
       }
       catch (IllegalArgumentException e)
       {
-         log.info("JSR-299 injection will not be available in Servlets, Filters etc. This facility is only available in Tomcat");
          tomcat = false;
       }
-      
+
       if (tomcat)
       {
          // Try pushing a Tomcat AnnotationProcessor into the servlet context
@@ -143,6 +149,7 @@
             Class<?> clazz = Reflections.classForName(WeldAnnotationProcessor.class.getName());
             Object annotationProcessor = clazz.getConstructor(WeldManager.class).newInstance(manager);
             sce.getServletContext().setAttribute(WeldAnnotationProcessor.class.getName(), annotationProcessor);
+            log.info("Tomcat 6 detected, JSR-299 injection will be available in Servlets, Filters etc.");
          }
          catch (Exception e)
          {
@@ -150,6 +157,36 @@
          }
       }
 
+      boolean jetty = true;
+      try
+      {
+         Reflections.classForName(Injector.class.getName());
+      }
+      catch (IllegalArgumentException e)
+      {
+         jetty = false;
+      }
+
+      if (jetty)
+      {
+         // Try pushing a Jetty Injector into the servlet context
+         try
+         {
+            Class<?> clazz = Reflections.classForName(JettyWeldInjector.class.getName());
+            Object injector = clazz.getConstructor(WeldManager.class).newInstance(manager);
+            sce.getServletContext().setAttribute(Injector.class.getName(), injector);
+            log.info("Jetty detected, JSR-299 injection will be available in Servlets, Filters etc.");
+         }
+         catch (Exception e)
+         {
+            log.error("Unable to create JettyWeldInjector. JSR-299 injection will not be available in Servlets, Filters etc.", e);
+         }
+      }
+
+      if (!tomcat && !jetty) {
+         log.info("No supported servlet container detected, JSR-299 injection will NOT be available in Servlets, Filters etc.");
+      }
+
       // Push the manager into the servlet context so we can access in JSF
       
       if (JspFactory.getDefaultFactory() != null)
@@ -171,11 +208,11 @@
       bootstrap.deployBeans().validateBeans().endInitialization();
       super.contextInitialized(sce);
    }
-   
+
    @Override
    protected ServletListener delegate()
    {
       return weldListener;
    }
-   
+
 }
Index: int/src/main/java/org/jboss/weld/environment/tomcat/WeldAnnotationProcessor.java
===================================================================
--- int/src/main/java/org/jboss/weld/environment/tomcat/WeldAnnotationProcessor.java	(revision 5874)
+++ int/src/main/java/org/jboss/weld/environment/tomcat/WeldAnnotationProcessor.java	(working copy)
@@ -1,53 +1,29 @@
 package org.jboss.weld.environment.tomcat;
 
-import java.lang.reflect.InvocationTargetException;
-import java.util.Map;
-import java.util.concurrent.ConcurrentHashMap;
-
-import javax.enterprise.context.spi.CreationalContext;
-import javax.enterprise.inject.spi.InjectionTarget;
-import javax.naming.NamingException;
-
 import org.apache.AnnotationProcessor;
+import org.jboss.weld.environment.servlet.inject.AbstractInjector;
 import org.jboss.weld.manager.api.WeldManager;
 
-public class WeldAnnotationProcessor implements AnnotationProcessor
+import javax.naming.NamingException;
+import java.lang.reflect.InvocationTargetException;
+
+public class WeldAnnotationProcessor extends AbstractInjector implements AnnotationProcessor
 {
-   
-   private final Map<Class<?>, InjectionTarget<?>> injectionTargets;
-   
-   private final WeldManager manager;
-   
    public WeldAnnotationProcessor(WeldManager manager)
    {
-      this.manager = manager;
-      this.injectionTargets = new ConcurrentHashMap<Class<?>, InjectionTarget<?>>();
+      super(manager);
    }
 
    public void processAnnotations(Object instance) throws IllegalAccessException, InvocationTargetException, NamingException
    {
-      // not data-race safe, however doesn't matter, as the injection target created for class A is interchangable for another injection target created for class A
-      // TODO Make this a concurrent cache when we switch to google collections
-      Class<?> clazz = instance.getClass();
-      if (!injectionTargets.containsKey(clazz))
-      {
-         injectionTargets.put(clazz, manager.createInjectionTarget(manager.createAnnotatedType(clazz)));
-      }
-      CreationalContext<Object> cc = manager.createCreationalContext(null);
-      InjectionTarget<Object> it = (InjectionTarget<Object>) injectionTargets.get(clazz);
-      it.inject(instance, cc);
+      inject(instance);
    }
 
    public void postConstruct(Object arg0) throws IllegalAccessException, InvocationTargetException
    {
-      // TODO Auto-generated method stub
-      
    }
    
    public void preDestroy(Object arg0) throws IllegalAccessException, InvocationTargetException
    {
-      // TODO Auto-generated method stub
-      
    }
-   
 }
Index: jetty-support/pom.xml
===================================================================
--- jetty-support/pom.xml	(revision 0)
+++ jetty-support/pom.xml	(revision 0)
@@ -0,0 +1,62 @@
+<?xml version="1.0" encoding="UTF-8"?>
+<project xmlns="http://maven.apache.org/POM/4.0.0" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:schemaLocation="http://maven.apache.org/POM/4.0.0 http://maven.apache.org/maven-v4_0_0.xsd">
+   <parent>
+      <artifactId>weld-servlet-parent</artifactId>
+      <groupId>org.jboss.weld.servlet</groupId>
+      <version>1.0.1-SNAPSHOT</version>
+   </parent>
+   <modelVersion>4.0.0</modelVersion>
+   <groupId>org.jboss.weld.servlet</groupId>
+   <artifactId>weld-jetty-support</artifactId>
+   <version>1.0.1-SNAPSHOT</version>
+   <packaging>jar</packaging>
+   <name>Weld Servlet Integration: Jetty Support</name>
+   <url>http://www.seamframework.org/Weld</url>
+   <licenses>
+      <license>
+         <name>Apache License, Version 2.0</name>
+         <distribution>repo</distribution>
+         <url>http://www.apache.org/licenses/LICENSE-2.0.html</url>
+      </license>
+   </licenses>
+
+   <dependencies>
+      <dependency>
+         <groupId>org.testng</groupId>
+         <artifactId>testng</artifactId>
+         <scope>test</scope>
+         <classifier>jdk15</classifier>
+         <exclusions>
+            <exclusion>
+               <artifactId>junit</artifactId>
+               <groupId>junit</groupId>
+            </exclusion>
+         </exclusions>
+      </dependency>
+   
+      <dependency>
+         <groupId>javax.servlet</groupId>
+         <artifactId>servlet-api</artifactId>
+         <scope>provided</scope>
+      </dependency>
+  
+      <dependency>
+         <groupId>org.mortbay.jetty</groupId>
+         <artifactId>jetty</artifactId>
+      </dependency>
+      <dependency>
+         <groupId>org.mortbay.jetty</groupId>
+         <artifactId>jetty-annotations</artifactId>
+      </dependency>
+
+   </dependencies>
+
+<!--
+   <scm>
+      <connection>scm:svn:http://anonsvn.jboss.org/repos/weld/servlet/trunk/jetty-support</connection>
+      <developerConnection>scm:svn:https://svn.jboss.org/repos/weld/servlet/trunk/jetty-support</developerConnection>
+      <url>http://fisheye.jboss.org/browse/weld/servlet/trunk/jetty-support</url>
+   </scm>
+-->
+
+</project>
Index: jetty-support/src/main/java/org/jboss/weld/environment/jetty/Injector.java
===================================================================
--- jetty-support/src/main/java/org/jboss/weld/environment/jetty/Injector.java	(revision 0)
+++ jetty-support/src/main/java/org/jboss/weld/environment/jetty/Injector.java	(revision 0)
@@ -0,0 +1,31 @@
+/*
+ * JBoss, Home of Professional Open Source.
+ * Copyright 2010, Red Hat Middleware LLC, and individual contributors
+ * as indicated by the @author tags. See the copyright.txt file in the
+ * distribution for a full listing of individual contributors.
+ *
+ * This is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation; either version 2.1 of
+ * the License, or (at your option) any later version.
+ *
+ * This software is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this software; if not, write to the Free
+ * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+ */
+
+package org.jboss.weld.environment.jetty;
+
+/**
+ * @author <a href="mailto:matija.mazi@gmail.com">Matija Mazi</a>
+ */
+public interface Injector
+{
+   void inject(Object targetInstance);
+}
\ No newline at end of file
Index: jetty-support/src/main/java/org/jboss/weld/environment/jetty/WeldAnnotationConfiguration.java
===================================================================
--- jetty-support/src/main/java/org/jboss/weld/environment/jetty/WeldAnnotationConfiguration.java	(revision 0)
+++ jetty-support/src/main/java/org/jboss/weld/environment/jetty/WeldAnnotationConfiguration.java	(revision 0)
@@ -0,0 +1,95 @@
+/*
+ * JBoss, Home of Professional Open Source.
+ * Copyright 2010, Red Hat Middleware LLC, and individual contributors
+ * as indicated by the @author tags. See the copyright.txt file in the
+ * distribution for a full listing of individual contributors.
+ *
+ * This is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation; either version 2.1 of
+ * the License, or (at your option) any later version.
+ *
+ * This software is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this software; if not, write to the Free
+ * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+ */
+
+package org.jboss.weld.environment.jetty;
+
+import org.mortbay.jetty.annotations.Configuration;
+import org.mortbay.jetty.plus.annotation.InjectionCollection;
+import org.mortbay.jetty.servlet.FilterHolder;
+import org.mortbay.jetty.servlet.ServletHolder;
+import org.mortbay.util.LazyList;
+
+import javax.servlet.ServletContext;
+import java.util.Iterator;
+
+/**
+ * This Configuration provides support for Weld injection into Servlets and javax.servlet.Filters,
+ * and (via its superclass) for JSR-250 annotations.
+ *
+ * @author <a href="mailto:matija.mazi@gmail.com">Matija Mazi</a>
+ */
+public class WeldAnnotationConfiguration extends Configuration
+{
+   public WeldAnnotationConfiguration() throws ClassNotFoundException
+   {
+   }
+
+   @Override
+   public void parseAnnotations() throws Exception
+   {
+      // handle @Resource
+      super.parseAnnotations();
+
+      ClassLoader previous = Thread.currentThread().getContextClassLoader();
+      ClassLoader webAppCL = getWebAppContext().getClassLoader();
+      Thread.currentThread().setContextClassLoader(webAppCL);
+      try
+      {
+         ServletContext sco = getWebAppContext().getServletContext();
+
+         //look thru _servlets
+         Iterator itor = LazyList.iterator(_servlets);
+         while (itor.hasNext())
+         {
+            ServletHolder holder = (ServletHolder) itor.next();
+            Class servlet = getWebAppContext().loadClass(holder.getClassName());
+            processAnnotations(servlet, _injections, sco);
+         }
+
+         //look thru _filters
+         itor = LazyList.iterator(_filters);
+         while (itor.hasNext())
+         {
+            FilterHolder holder = (FilterHolder) itor.next();
+            Class filter = getWebAppContext().loadClass(holder.getClassName());
+            processAnnotations(filter, _injections, sco);
+         }
+
+         //look thru _listeners
+         itor = LazyList.iterator(_listeners);
+         while (itor.hasNext())
+         {
+            Object listener = itor.next();
+            processAnnotations(listener.getClass(), _injections, sco);
+         }
+      }
+      finally
+      {
+         Thread.currentThread().setContextClassLoader(previous);
+      }
+   }
+
+   protected void processAnnotations(Class clazz, InjectionCollection injections, ServletContext sco)
+   {
+      injections.add(new WeldInjection(clazz, sco));
+   }
+}
Index: jetty-support/src/main/java/org/jboss/weld/environment/jetty/WeldInjection.java
===================================================================
--- jetty-support/src/main/java/org/jboss/weld/environment/jetty/WeldInjection.java	(revision 0)
+++ jetty-support/src/main/java/org/jboss/weld/environment/jetty/WeldInjection.java	(revision 0)
@@ -0,0 +1,133 @@
+/*
+ * JBoss, Home of Professional Open Source.
+ * Copyright 2010, Red Hat Middleware LLC, and individual contributors
+ * as indicated by the @author tags. See the copyright.txt file in the
+ * distribution for a full listing of individual contributors.
+ *
+ * This is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation; either version 2.1 of
+ * the License, or (at your option) any later version.
+ *
+ * This software is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this software; if not, write to the Free
+ * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+ */
+
+package org.jboss.weld.environment.jetty;
+
+import org.mortbay.jetty.plus.annotation.Injection;
+import org.mortbay.log.Log;
+
+import javax.naming.NamingException;
+import javax.servlet.ServletContext;
+
+/**
+ * This is a hack: it pretends to be an injection into a single injection point
+ * (concretely, a setter method) as its superclass, but really it handles all the
+ * injection points for a single injection target (eg. a Servlet class).
+ *
+ * @author <a href="mailto:matija.mazi@gmail.com">Matija Mazi</a>
+ */
+public class WeldInjection extends Injection
+{
+   private ServletContext sco;
+   private Injector injector;
+
+   public WeldInjection(Class clazz, ServletContext sco)
+   {
+      this.sco = sco;
+      super.setTargetClass(clazz);
+      try
+      {
+         super.setTarget(clazz.getMethod("toString")); // pretend
+      }
+      catch (NoSuchMethodException ignore) { }
+   }
+
+   @Override
+   public void inject(Object injectable)
+   {
+      if (injector == null)
+      {
+         injector = (Injector) sco.getAttribute(Injector.class.getName());
+      }
+      if (injector == null)
+      {
+         Log.warn("Can't find Injector in the servlet context so injection is not available for " + getTargetClass() + ". (Injection into Listeners is not supported in Jetty.)");
+      }
+      else
+      {
+         injector.inject(injectable);
+      }
+   }
+
+   @Override
+   public Object lookupInjectedValue() throws NamingException
+   {
+      throw new UnsupportedOperationException("lookupInjectedValue");
+   }
+
+/*
+   @Override
+   public void setTargetClass(Class clazz)
+   {
+      throw new UnsupportedOperationException("setTargetClass");
+   }
+
+   @Override
+   public void setJndiName(String jndiName)
+   {
+      throw new UnsupportedOperationException("setJndiName");
+   }
+
+   @Override
+   public void setMappingName(String mappingName)
+   {
+      throw new UnsupportedOperationException("setMappingName");
+   }
+
+   @Override
+   public void setTarget(Member target)
+   {
+      throw new UnsupportedOperationException("setTarget");
+   }
+
+   @Override
+   public void setTarget(Class clazz, String targetName, Class targetType)
+   {
+      throw new UnsupportedOperationException("setTarget");
+   }
+
+   @Override
+   public void injectField(Field field, Object injectable)
+   {
+      throw new UnsupportedOperationException("injectField");
+   }
+
+   @Override
+   public void injectMethod(Method method, Object injectable)
+   {
+      throw new UnsupportedOperationException("injectMethod");
+   }
+
+   @Override
+   public String getJndiName()
+   {
+      throw new UnsupportedOperationException("getJndiName");
+   }
+
+   @Override
+   public String getMappingName()
+   {
+      throw new UnsupportedOperationException("getMappingName");
+   }
+
+*/
+}
Index: pom.xml
===================================================================
--- pom.xml	(revision 5874)
+++ pom.xml	(working copy)
@@ -25,6 +25,7 @@
       <module>int</module>
       <module>build</module>
       <module>support</module>
+      <module>jetty-support</module>
       <module>tests</module>
    </modules>
    
@@ -60,6 +61,8 @@
       <!-- Use JSF 2 for all extensions support, despite core using JSF 1.2 -->
       <jsf.version>2.0.0-RC</jsf.version>
       <tomcat.version>6.0.20</tomcat.version>
+      <jetty.version>6.1.21</jetty.version>
+
       <uel.glassfish.version>2.1.2-b04</uel.glassfish.version>
       <slf4j.version>1.5.10</slf4j.version>
       <!-- Testing deps -->
@@ -134,6 +137,11 @@
             <artifactId>weld-servlet-int</artifactId>
             <version>${project.version}</version>
          </dependency>
+         <dependency>
+            <groupId>org.jboss.weld.servlet</groupId>
+            <artifactId>weld-jetty-support</artifactId>
+            <version>${project.version}</version>
+         </dependency>
 
          <dependency>
             <groupId>org.apache.tomcat</groupId>
@@ -148,6 +156,17 @@
          </dependency>
 
          <dependency>
+            <groupId>org.mortbay.jetty</groupId>
+            <artifactId>jetty</artifactId>
+            <version>${jetty.version}</version>
+         </dependency>
+         <dependency>
+            <groupId>org.mortbay.jetty</groupId>
+            <artifactId>jetty-annotations</artifactId>
+            <version>${jetty.version}</version>
+         </dependency>
+
+         <dependency>
             <groupId>org.glassfish.web</groupId>
             <artifactId>el-impl</artifactId>
             <version>${uel.glassfish.version}</version>
